<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fmp="http://www.filemaker.com/fmpxmlresult">

<!--

tab-notes.xsl	(Notes de lecture, version 1.6 - novembre 2007)


Transforme les donnees exportéees de notes.fp5 en fichier texte au format tabulation, avec :

- encodage des caracteres : selon parametres en entree (cf. $wichEncoding)
- dans les champs Notes et citations les caracteres tab/eol sont remplaces par des chaines passees en parametres, 
  et ils sont inhibes dans tous les autres champs (remplaces par 1 espace)
- ajout d'une 1e ligne avec le nom des colonnes

Ordre des data en entree : id L, id Art, ref, notes, extraits, mots cles, obs, modifLe
Tous les champs sont conserves

-->


<!--  Constantes -->
<xsl:variable name="cr"> <xsl:text>&#13;</xsl:text> </xsl:variable>
<xsl:variable name="lf"> <xsl:text>&#10;</xsl:text> </xsl:variable>
<xsl:variable name="wineol"> <xsl:text>&#13;&#10;</xsl:text> </xsl:variable>
<xsl:variable name="FMeol_in"> <xsl:text>&#10;</xsl:text> </xsl:variable>

<!--		PARAMETRES importes : chaine extraite du dernier champ du 1er record
		structure de la chaine : param wichEncoding[prm1]param FMtab_out[prmTAB]param FMeol_out[prmEOL]

		Note : wichEncoding est pour l'instant inutile puisque fixe par stylesSheet appelante 
		mais prevu au cas ou je trouverais une solution pour parametrer l'attribut encoding de <xsl:stylesheet>
-->
<xsl:variable name="params"> <xsl:value-of select="fmp:FMPXMLRESULT/fmp:RESULTSET/fmp:ROW[1]/fmp:COL[last()]"/> </xsl:variable>
<xsl:param name="FMtab_out"><xsl:value-of select="substring-before(substring-after($params,'[prm1]'), '[prmTAB]')"/></xsl:param>
<xsl:param name="FMeol_out"><xsl:value-of select="substring-before(substring-after($params,'[prmTAB]'), '[prmEOL]')"/></xsl:param>

<!-- Separateurs d'enregistrement et de champ -->
<xsl:param name="newrecord">
	<xsl:call-template name="recordSeparator">
	<xsl:with-param name="encoding" select ="$wichEncoding" />
	</xsl:call-template>
</xsl:param>
<xsl:param name="newfield"> <xsl:text>&#9;</xsl:text> </xsl:param>


<!--  main template -->
<xsl:template match="fmp:FMPXMLRESULT">


	<!-- nom colonnes en en-tete -->
	<xsl:value-of select="concat('CodeL', $newfield, 'CodeArt', $newfield, 'RefBiblio', $newfield, 'Notes', $newfield, 'Extraits', $newfield, 'MotsCles', $newfield, 'Obs', $newfield, 'ModifLe')" />
	<xsl:value-of select="$newrecord" />

	<!-- data -->
	<xsl:for-each select="fmp:RESULTSET/fmp:ROW">
		<xsl:call-template name="delete_separators"> <xsl:with-param name="str" select ="fmp:COL[1]" /> </xsl:call-template>
		<xsl:value-of select="$newfield"/>
		<xsl:call-template name="delete_separators"> <xsl:with-param name="str" select ="fmp:COL[2]" /> </xsl:call-template>
		<xsl:value-of select="$newfield"/>
		<xsl:call-template name="delete_separators"> <xsl:with-param name="str" select ="fmp:COL[3]" /> </xsl:call-template>
		<xsl:value-of select="$newfield"/>

		<!-- not & cit -->
		<xsl:call-template name="replace_separators"> <xsl:with-param name="str" select ="fmp:COL[4]" /> </xsl:call-template>
		<xsl:value-of select="$newfield"/>
		<xsl:call-template name="replace_separators"> <xsl:with-param name="str" select ="fmp:COL[5]" /> </xsl:call-template>
		<xsl:value-of select="$newfield" />

		<xsl:call-template name="delete_separators"> <xsl:with-param name="str" select ="fmp:COL[6]" /> </xsl:call-template>
		<xsl:value-of select="$newfield" />
		<xsl:call-template name="delete_separators"> <xsl:with-param name="str" select ="fmp:COL[7]" /> </xsl:call-template>
		<xsl:value-of select="$newfield" />
		<!-- date -->
		<xsl:value-of select="fmp:COL[8]" />
		<xsl:value-of select="$newrecord" />
	</xsl:for-each>
</xsl:template>

<xsl:template name="recordSeparator">
<xsl:param name="encoding"/>
	<xsl:choose>
		<xsl:when test="$encoding=1"><xsl:value-of select="$cr"/></xsl:when>
		<xsl:when test="$encoding=2"><xsl:value-of select="$wineol"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="$lf"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Remplace les cars separateurs par ceux passes en parametre -->
<xsl:template name="replace_separators">
<xsl:param name="str"/>
	<xsl:variable name="tmp">
		<xsl:call-template name="replaceString">
			<xsl:with-param name="str" select ="$str"/>
			<xsl:with-param name="from" select ="$FMeol_in"/>
			<xsl:with-param name="to" select ="$FMeol_out"/>
		</xsl:call-template>
	</xsl:variable>
	<xsl:call-template name="replaceString">
		<xsl:with-param name="str" select ="$tmp"/>
		<xsl:with-param name="from" select ="$newfield"/>
		<xsl:with-param name="to" select ="$FMtab_out"/>
	</xsl:call-template>
</xsl:template>

<!-- inhibe les cars separateurs (remplaces par un espace) -->
<xsl:template name="delete_separators">
<xsl:param name="str"/>
	<xsl:variable name="tmp">
		<xsl:call-template name="replaceString">
			<xsl:with-param name="str" select ="$str"/>
			<xsl:with-param name="from" select ="$FMeol_in"/>
			<xsl:with-param name="to" select ="' '"/>
		</xsl:call-template>
	</xsl:variable>
	<xsl:call-template name="replaceString">
		<xsl:with-param name="str" select ="$tmp"/>
		<xsl:with-param name="from" select ="$newfield"/>
		<xsl:with-param name="to" select ="' '"/>
	</xsl:call-template>
</xsl:template>

<!-- ****************** UTILITAIRES ****************** -->

<!--	 	replaceString $str, $from, $to
		rech/remplacement simple dans une chaine (recursif)
-->
<xsl:template name="replaceString">
	<xsl:param name="str"/>
	<xsl:param name="from"/>
	<xsl:param name="to"/>
	<xsl:choose>
		<xsl:when test="contains($str,$from)">
			<xsl:value-of select="substring-before($str,$from)"/>
			<xsl:value-of select="$to"/>
			<xsl:call-template name="replaceString">
				<xsl:with-param name="str" select ="substring-after($str,$from)"/>
				<xsl:with-param name="from" select ="$from"/>
				<xsl:with-param name="to" select ="$to"/>
			</xsl:call-template>
		 </xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$str"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
